.. This file is no longer used, we redirect to autoapi/xdoctest/index.html

:github_url: https://github.com/Erotemic/xdoctest

.. The __init__ files contains the top-level documentation overview
.. automodule:: xdoctest.__init__
   :show-inheritance:

.. toctree::
   :maxdepth: 8
   :caption: Package Layout

   xdoctest


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

